QuickNotifier class

Constructors

QuickNotifier({required Map<Key, dynamic Function()> updates, Key? dependency})

Properties

dependency ↔ Key?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updates ↔ Map<Key, dynamic Function()>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateDependencies() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited