QuickReference class

Constructors

QuickReference(String _key, Type type)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type
final
value ↔ dynamic
getter/setter pair

Methods

lock() → QuickReference
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify() → QuickReference
store() → QuickReference
to(dynamic newValue) → QuickReference
toString() → String
A string representation of this object.
inherited
unlock() → QuickReference

Operators

operator ==(Object other) → bool
The equality operator.
inherited